import React, {useState} from "react";
import reg from "../assets/seller-reg/sellerreg.svg";
import { useNavigate } from "react-router-dom";

function Create_account() {
  const navigate = useNavigate();
  const Infoicon = () =>(
    <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke-width="1.5" stroke="currentColor" class="w-5 h-5 inline-block ml-1">
    <path stroke-linecap="round" stroke-linejoin="round" d="M12 8v4m0 4h.01M12 20a8 8 0 100-16 8 8 0 000 16z" />
  </svg>
);
  const [phoneNumber, setPhoneNumber] = useState("");
  const [phoneNumberError, setPhoneNumberError] = useState("");

  const handlePhoneNumberChange = (e) => {
    const value = e.target.value;
    const phoneRegex = /^[0-9]{0,10}$/; // Allows only numbers and max 10 digits

    if (!phoneRegex.test(value)) {
      setPhoneNumberError("*Phone number must contain only numbers and be 10 digits.");
    } else {
      setPhoneNumberError("");
    }

    setPhoneNumber(value);
  };

  const handleSendOtp = (e) => {
    e.preventDefault();
    if (phoneNumber.length !== 10) {
      setPhoneNumberError("Phone number must be exactly 10 digits.");
    } else {
      setPhoneNumberError("");
      alert("OTP Sent Successfully!");
      navigate("/recive-otp", { state: { phone: phoneNumber } });
    }
  };
  return (
    <>
      <div className="flex flex-col items-center  min-h-screen bg-[#E9FAFF] p-4 font-montserrat">
      {/* Header */}
      <div className="w-full text-left max-w-6xl px-2 md:px-0 mb-6 mt-6 ml-30 flex">
        <h1 className="text-[20px] md:text-[48.31px] font-bold text-[#030A1E] relative">
          OMPOI - Seller
        </h1>
      </div>

      <div className="flex flex-col md:flex-row items-center justify-center w-full max-w-2xl md:max-w-5xl bg-[#FFFFFF] p-2 rounded-[32.6px] shadow-lg relative">
        {/* Left Section - Image */}
        <div className="w-fit md:w-1/2 flex justify-center md:pr-8 relative gap-1 md:gap-0">
          <img src={reg} alt="Login Illustration" className="max-w-xs md:max-w-lg p-1" />
          <div className="hidden md:block absolute right-0 top-[7px] bottom-0 w-[1px] h-[400px] bg-[#E2E7EE]" />
        </div>

        {/* Right Section - OTP Registration */}
        <div className="w-full md:w-1/2 flex flex-col justify-center items-center  mt-[40px] md:mt-7 p-2 md:p-5">
          <h2 className="text-[18px] md:text-[20px] font-semibold mb-2 self-center">
            Merchant Registration
          </h2>
          <p className="text-[16px] md:text-[12.91px] font-semibold mt-[5px] justify-center items-center self-center mb-[10px] md:mb-[50px]">
            OTP-Verification
          </p>

          <form className=" " onSubmit={handleSendOtp}>
            <div className=" ml-[200px] justify-center items-center mb-8">
              <label
                className={`text-[10px] md:text-[18px] text-[#8B9BB1] p-[0.5px] px-1 relative top-1 left-6 bg-white ${
                  phoneNumberError ? "text-red-500" : "text-green-500"
                }`}
              >
                Phone Number
              </label>
              <input
                  type="text"
                  id="phoneNumber"
                  value={phoneNumber}
                  onChange={handlePhoneNumberChange}
                  maxLength="10"
                  required
                  className={`w-[280px] p-2 md:p-3 mr-[20rem] border border-[#C4CFDE] rounded-[12px] mt-[-10px] text-[10px] md:text-[18px] focus:outline-none ${phoneNumberError ? "border-red-500" : "border-green-500 "} `}
                  placeholder="+91"
                />
              {phoneNumberError && (
                <p className="text-red-500 text-[10px] mt-1">{phoneNumberError} <Infoicon /> </p>
              )}
            </div>

            <div className="flex justify-center items-center">
              <button
                type="submit"
                className="w-30 md:w-52 px-2 md:px-10 bg-[#fdba74] text-[#020617] py-1.5 md:py-3.5 rounded-[20.8px] md:rounded-[32.6px] mb-14 font-semibold focus:outline-none"
              >
                Send OTP
              </button>
            </div>
          </form>
        </div>

        {/* Absolute right-side design, hidden on small screens */}
        <div className="hidden md:flex  mr-[-170px] mt-[-300px]">
            <div className="border-[2px] border-[#171451] right-5  w-10 h-10 bg-[#E2E7EE] rounded-full" />
              <div className="rounded-full bg-[#171451] p-1 w-5 h-5 mx-[-30px] my-[10px] ">
                <div className="w-[1px] h-[120px] mt-[25px] ml-[5px] bg-[#D1D5DB] border-dotted border-[1px]" >
                  <div className="border-[2px] border-[#D1D5DB] right-5  w-10 h-10 mt-[120px] ml-[-20px] bg-[#E2E7EE] rounded-full ">
                  <div className="rounded-full bg-[#D1D5DB] p-1 w-5 h-5 mx-[8px] my-[8px] ">
                    <div className="w-[1px] h-[120px] mt-[25px] ml-[5px] bg-[#D1D5DB] border-dotted border-[1px] ">
                      <div className=" border-[2px] border-[#D1D5DB] right-5  w-10 h-10 mt-[120px] ml-[-20px] bg-[#E2E7EE] rounded-full ">
                      <div className="rounded-full bg-[#D1D5DB] p-1 w-5 h-5 mx-[8px] my-[8px] ">
                      </div>  
                      </div>
                    </div>
                    </div>
                  </div>
                </div>
              </div>
            </div>
        </div>
    </div>
</>
  );
}

export default Create_account;
