import React from "react";
import { useState, useEffect } from "react";
import reg from "../assets/seller-reg/sellerreg.svg";
import { useLocation, useNavigate } from "react-router-dom";

function Send_otp() {
    const navigate = useNavigate();
    const Infoicon = () =>(
        <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke-width="1.5" stroke="currentColor" class="w-5 h-5 inline-block ml-1">
        <path stroke-linecap="round" stroke-linejoin="round" d="M12 8v4m0 4h.01M12 20a8 8 0 100-16 8 8 0 000 16z" />
      </svg>
    );  
  const [countdown, setCountdown] = useState(30);
  const [isCounting, setIsCounting] = useState(true);
  const [generatedOtp, setGeneratedOtp] = useState("");
  const [userOtp, setUserOtp] = useState(["", "", "", "", "", ""]);
  const [message, setMessage] = useState({ text: "", color: "" });

  useEffect(() => {
    let timer;
    if (isCounting && countdown > 0) {
      timer = setInterval(() => {
        setCountdown((prev) => prev - 1);
      }, 1000);
    } else if (countdown === 0) {
      setIsCounting(true);
      const otp = Math.floor(100000 + Math.random() * 900000).toString(); // Generate 6-digit OTP
      setGeneratedOtp(otp);
      alert(`Your OTP is: ${otp}`);
    }

    return () => clearInterval(timer);
  }, [isCounting, countdown]);

  const handleResendOtp = () => {
    setCountdown(30);
    setIsCounting(true);
    setMessage({ text: "", color: "" });
    setUserOtp(["", "", "", "", "", ""]);
  };
  const handleOtpChange = (index, value) => {
    if (!isNaN(value) && value.length <= 1) {
      const newOtp = [...userOtp];
      newOtp[index] = value;
      setUserOtp(newOtp);
    }
  };
  const verifyOtp = () => {
    const enteredOtp = userOtp.join("");
    if (enteredOtp === generatedOtp) {
      setMessage({ text: "*OTP Successfully Entered!", color: "text-green-500" });
      setTimeout(() => {
        navigate("/registration");
    }, 1000);
    } else {
      setMessage({ text: "*Invalid OTP, Please Try Again!", color: "text-red-500" });
    }
  };
  const donot = () => {
    alert("Please wait a second, server work for you! ");
  };
  const location = useLocation();
  const phone = location.state?.phone || "No Phone Number Provided";
  return (
    <>
      <div className="flex flex-col items-center  min-h-screen bg-[#E9FAFF] p-4 font-montserrat">
        {/* Header */}
        <div className="w-full text-left max-w-6xl px-2 md:px-0 mb-6 mt-6 ml-30 flex">
          <h1 className="text-[20px] md:text-[48.31px] font-bold text-[#030A1E] relative">
            OMPOI - Seller
          </h1>
        </div>

        <div className="flex flex-col md:flex-row items-center justify-center w-full max-w-2xl md:max-w-5xl bg-[#FFFFFF] p-2 rounded-[32.6px] shadow-lg relative">
          {/* Left Section - Image */}
          <div className="w-fit md:w-1/2 flex justify-center md:pr-8 relative gap-1 md:gap-0">
            <img
              src={reg}
              alt="Login Illustration"
              className="max-w-xs md:max-w-lg p-3"
            />
            <div className="hidden md:block absolute right-0 top-[7px] bottom-0 w-[1px] h-[400px] bg-[#E2E7EE]" />
          </div>

          {/* Right Section - OTP Registration */}
          <div className="w-full md:w-1/2 flex flex-col items-center md:pl-0 mt-[40px] md:mt-[70px] p-2 md:p-6">
            <h2 className="text-[18px] md:text-[24.91px] font-semibold mb-[2px] self-center">
              Merchant Registration
            </h2>
            <p className="text-[16px] md:text-[12.91px] font-semibold mt-[5px] justify-center items-center self-center mb-[18px]">
              OTP-Verification
            </p>
            <div className="text-[10px] md:text-[12.91px] font-[10px] mt-[5px] justify-center items-center self-center mb-[5px]">
              <span className="text-black">
                We Will send you a one time password on
              </span>
              <br />
              <span className="text-black">
                <p className="text-center">
                  this <span className="font-extrabold">Mobile Number</span>{" "}
                </p>
              </span>
              <br />
              <div className="mb-[20px]">
                <p className="text-center">
                  <strong>+91 &nbsp;&nbsp;&nbsp; {phone}</strong>
                </p>
              </div>
            </div>
            <div className="flex justify-between items-center">
              <div className="mb-[10px]">
                {userOtp.map((digit, index) => (
                <input
                  type="text"
                  key={index}
                  value={digit}
                  onChange={(e) => handleOtpChange(index, e.target.value)}
                  maxLength="1"
                  className="w-5 md:w-10 h-5 md:h-10 rounded-full bg-[#D1D5DB] border-[2px] ml-[5px] md:ml-[10px] border-[#fdba74] hover:border-orange-500 focus:outline-none text-center "
                />))}
                {message.text && <p className={`mt-4 ml-4 text-[10px] font-semibold ${message.color}`}>{message.text} <Infoicon /> </p>}
              </div>
            </div>
            <div className="mb-[10px]">
              <p className="text-[16px] md:text-[20px] font-semibold text-[#675B5B]">
                {`00:${countdown < 10 ? `0${countdown}` : countdown}`}
              </p>
            </div>
            <div className="flex flex-col md:flex-row justify-center gap-5 w-full text-[12px] mb-8 font-semibold">
              <p
                className="text-center md:text-[#030A1E]  hover:underline cursor-pointer"
                onClick={donot}
              >
                Do not send OTP?
              </p>
              <p
                className="text-center text-[#FFBD69] md:text-[#FFBD69] hover:underline cursor-pointer"
                onClick={handleResendOtp}
              >
                Send Otp
              </p>
            </div>
            <div>
              <button
                onClick={verifyOtp}
                type="submit"
                className="w-30 md:w-52 px-2 md:px-10 text-[15px] md:text-[20px] bg-[#FFBD69] text-[#030A1E] py-1.5 md:py-3.5 rounded-[20.8px] md:rounded-[32.6px] mb-8 font-semibold focus:outline-none"
              >
                Verify Otp
              </button>
            </div>
          </div>

          {/* Absolute right-side design, hidden on small screens */}
          <div className="hidden md:flex  mr-[-170px] mt-[-320px] ">
            <div className="border-[2px] border-[#171451] right-5  w-10 h-10 bg-[#E2E7EE] rounded-full">
              <div className="rounded-full bg-[#171451] p-1 w-5 h-5 mx-[8px] my-[8px] ">
                <div className="w-[1px] h-[120px] mt-[25px] ml-[5px] bg-[#D1D5DB] border-dotted border-[1px] ">
                  <div className="border-[2px] border-[#D1D5DB] right-5  w-10 h-10 mt-[120px] ml-[-20px] bg-[#E2E7EE] rounded-full ">
                    <div className="rounded-full bg-[#D1D5DB] p-1 w-5 h-5 mx-[8px] my-[8px] ">
                      <div className="w-[1px] h-[120px] mt-[25px] ml-[5px] bg-[#D1D5DB] border-dotted border-[1px] ">
                        <div className="border-[2px] border-[#D1D5DB] right-5  w-10 h-10 mt-[120px] ml-[-20px] bg-[#E2E7EE] rounded-full ">
                          <div className="rounded-full bg-[#D1D5DB] p-1 w-5 h-5 mx-[8px] my-[8px] "></div>
                        </div>
                      </div>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>
    </>
  );
}

export default Send_otp;




{/*{userOtp.map((digit, index) => (
                <input
                  type="text"
                   onChange={(e) => handleOtpChange(index, e.target.value)}
                  maxLength="1"
                  key={index}
                  value={digit}
                  className="w-5 md:w-10 h-5 md:h-10 rounded-full bg-[#D1D5DB] border-[2px] ml-[5px] md:ml-[10px] border-[#fdba74] hover:border-orange-500 focus:outline-none text-center "
                />))}
                {userOtp.map((digit, index) => (
                <input
                  type="text"
                   onChange={(e) => handleOtpChange(index, e.target.value)}
                   key={index}
                   value={digit}
                  maxLength="1"
                  className="w-5 md:w-10 h-5 md:h-10 rounded-full bg-[#D1D5DB] border-[2px] ml-[5px] md:ml-[10px] border-[#fdba74] hover:border-orange-500 focus:outline-none text-center "
                />))}
                {userOtp.map((digit, index) => (
                <input
                  type="text"
                   onChange={(e) => handleOtpChange(index, e.target.value)}
                   key={index}
                   value={digit}
                  maxLength="1"
                  className="w-5 md:w-10 h-5 md:h-10 rounded-full bg-[#D1D5DB] border-[2px]  ml-[5px] md:ml-[10px] border-[#fdba74] hover:border-orange-500 focus:outline-none text-center "
                />))}
                {userOtp.map((digit, index) => (
                <input
                  key={index}  
                  type="text"
                  value={digit}
                   onChange={(e) => handleOtpChange(index, e.target.value)}
                  maxLength="1"
                  className="w-5 md:w-10 h-5 md:h-10 rounded-full bg-[#D1D5DB] border-[2px]  ml-[5px] md:ml-[10px] border-[#fdba74] hover:border-orange-500 focus:outline-none text-center "
                />))}
                {userOtp.map((digit, index) => (
                <input
                  key={index}
                  value={digit}
                  onChange={(e) => handleOtpChange(index, e.target.value)}
                  type="text"
                  maxLength="1"
                  className="w-5 md:w-10 h-5 md:h-10 rounded-full bg-[#D1D5DB] border-[2px] ml-[5px] md:ml-[10px] border-[#fdba74] hover:border-orange-500 focus:outline-none text-center "
                />
                ))} */}