import React, { useState } from "react";
import key from "../assets/seller-login/first!.svg";
import icon from "../assets/seller-login/mail.svg";
import icon1 from "../assets/seller-login/eye.svg";
import icon2 from "../assets/seller-login/open-eye.svg";
import { useNavigate } from "react-router-dom";

function Seller_login() {
  const navigate = useNavigate();
        const goto = () => {
            navigate("/create-account");
        };
  const Infoicon = () =>(
    <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke-width="1.5" stroke="currentColor" class="w-5 h-5 inline-block ml-1">
    <path stroke-linecap="round" stroke-linejoin="round" d="M12 8v4m0 4h.01M12 20a8 8 0 100-16 8 8 0 000 16z" />
  </svg>
);
  const [merchantId, setMerchantId] = useState("");
  const [password, setPassword] = useState("");
  const [merchantIdError, setMerchantIdError] = useState("");
  const [passwordError, setPasswordError] = useState("");
  const [showPassword, setShowPassword] = useState(false);

  const validateMerchantId = (id) => {
    const pattern = /^[A-Za-z]{4}\d{5}$/;
    if (!pattern.test(id)) {
      setMerchantIdError("*Merchant ID must be 4 letters followed by 5 numbers");
      return false;
    }
    setMerchantIdError("");
    return true;
  };

  const validatePassword = (pass) => {
    const pattern = /^(?=.*[a-zA-Z]{4,})(?=.*\d{3,})(?=.*[^a-zA-Z\d]{2,}).{9,}$/;
    if (!pattern.test(pass)) {
      setPasswordError(
        "*Password must contain at least 4 letters, 2 special characters, and 3 numbers"
      );
      return false;
    }
    setPasswordError("");
    return true;
  };

  return (
    <div className="flex flex-col items-center min-h-screen bg-[#E9FAFF] p-4 font-montserrat">
      {/* Header */}
      <div className="w-full text-left max-w-6xl px-2 md:px-0 mb-4 mt-4 ml-10">
        <h1 className="text-[20px] text-center md:text-start md:text-[48.31px] font-[700px] text-[#030A1E] self-start">OMPOI - Seller</h1>
      </div>

      <div className="flex flex-col md:flex-row items-center justify-center min-w-9/10 min-h-9/10
       mb-10 bg-[#FFFFFF] p-5 rounded-[32.6px] shadow-lg ">
        {/* Left Section - Image */}
        <div className="w-full md:w-1/2 flex justify-start ml-10  relative">
          <img src={key} alt="Login Illustration" className="max-w-xs md:w-lg p-2" />
          <div className="hidden md:block absolute right-0 top-[-7px] bottom-0 w-[1px] left-[450px] h-[400px] bg-[#E2E7EE] "></div>
        </div>

        {/* Right Section - Login Form */}
        <div className="w-full md:w-3/4 h-1/3 flex flex-col items-center md:pl-8 mt-6 md:mt-7">
          <h2 className="text-2xl font-semibold mb-0 self-center p-5 ">Login</h2>

          <form className="w-full max-w-3/4 p-4">
            <div className="relative mb-8">
              <label
                className={`text-[10px] md:text-[18px] text-[#8B9BB1] p-[0.5px] px-1 relative top-1 left-6 bg-white ${
                  merchantIdError ? "text-red-500" : "text-green-500"
                }`}
              >
                Merchant ID
              </label>
              <input
                type="text"
                id="merchantId"
                className={`w-full p-2 md:p-3 border border-[#C4CFDE] rounded-[12px] mt-[-10px] text-[10px] md:text-[18px] focus:outline-none ${
                  merchantIdError ? "border-red-500" : "border-green-500 "
                }`}
                required
                placeholder="Enter ID"
                value={merchantId}
                onChange={(e) => {
                  setMerchantId(e.target.value);
                  validateMerchantId(e.target.value);
                }}
              />
              <span className="flex inset-y-0 justify-end">
                <img src={icon} alt="icon" className="relative items-center w-3 md:w-5 h-3 md:h-5 mt-[-25px] md:mt-[-35px] mr-[12px] md:mr-[20px]" />
              </span>
              {merchantIdError && <p className="text-red-500 text-[10px]">{merchantIdError} <Infoicon /> </p>}
            </div>

            <div className="relative mb-4">
              <label
                className={`text-[10px] md:text-[18px] text-[#8B9BB1] p-[0.5px] px-1 relative top-1 left-6 bg-white ${
                  passwordError ? "text-red-500" : "text-green-500"
                }`}
              >
                Password
              </label>
              <input
                type={showPassword ? "text" : "password"}
                id="password"
                className={`w-full p-2 md:p-3 border border-[#C4CFDE] rounded-[12px] mt-[-10px] text-[10px] md:text-[18px] focus:outline-none ${
                  passwordError ? "border-red-500" : "border-green-500 " 
                }`}
                required
                placeholder="Enter your password"
                value={password}
                onChange={(e) => {
                  setPassword(e.target.value);
                  validatePassword(e.target.value);
                }}
              />
              <span className="flex inset-y-0 justify-end cursor-pointer" onClick={() => setShowPassword(!showPassword)}>
                <img src={showPassword ? icon2 : icon1} alt="icon" className="relative items-center w-3 md:w-5 h-3 md:h-5 mt-[-25px] md:mt-[-35px] mr-[12px] md:mr-[20px]" />
              </span>
              {passwordError && <p className="text-red-500 text-[10px]">{passwordError} <Infoicon /></p>}
            </div>

            <div className="flex justify-between w-full text-sm mb-8">
              <p className="text-[#030A1E] text-[10px] md:text-[12px]  hover:underline cursor-pointer" >Forgot Password?</p>
              <p className="text-[#FFBD69] text-[10px] md:text-[12px] hover:underline cursor-pointer" onClick={goto} >Create an Account</p>
            </div>
            <div className="flex justify-center items-center">
              <button className="w-52 px-10 bg-yellow-500 text-[#020617] py-3.5 rounded-[32.6px] mb-5 mt-2 font-semibold">
                Sign in
              </button>
            </div>
            <div className="flex justify-center items-center">
              <button className="w-52 px-10 border border-[#fdba74] text-[#020617] py-3.5 rounded-[32.6px] font-semibold">
                Check Status
              </button>
            </div>
          </form>
        </div>
      </div>
    </div>
  );
}

export default Seller_login;
